@@ -13,7 +13,7 @@ import re
 import time
 from contextlib import suppress
 
-from typing import Any, Awaitable, Callable, Optional
+from typing import Any, Awaitable, Callable, Dict, Optional, Tuple, Union
 
 import clu
 import clu.base
@@ -67,9 +67,9 @@ class BaseCommand(asyncio.Future, StatusMixIn[CommandStatus]):
 
     def __init__(
         self,
-        commander_id: int | str = 0,
-        command_id: int | str = 0,
-        consumer_id: int | str = 0,
+        commander_id: Union[int, str] = 0,
+        command_id: Union[int, str] = 0,
+        consumer_id: Union[int, str] = 0,
         actor: clu.base.BaseActor = None,
         parent: BaseCommand = None,
         status_callback: Callable[[CommandStatus], Any] = None,
@@ -103,7 +103,7 @@ class BaseCommand(asyncio.Future, StatusMixIn[CommandStatus]):
         )
 
     @property
-    def status(self) -> CommandStatus | None:
+    def status(self) -> Union[CommandStatus, None]:
         """Returns the status."""
 
         return self._status
@@ -127,8 +127,8 @@ class BaseCommand(asyncio.Future, StatusMixIn[CommandStatus]):
 
     def set_status(
         self,
-        status: CommandStatus | str,
-        message: dict[str, Any] = None,
+        status: Union[CommandStatus, str],
+        message: Dict[str, Any] = None,
         silent: bool = False,
         **kwargs,
     ) -> BaseCommand:
@@ -210,7 +210,7 @@ class BaseCommand(asyncio.Future, StatusMixIn[CommandStatus]):
     def write(
         self,
         message_code: str = "i",
-        message: dict[str, Any] = None,
+        message: Dict[str, Any] = None,
         broadcast: bool = False,
         **kwargs,
     ):
@@ -241,7 +241,7 @@ class BaseCommand(asyncio.Future, StatusMixIn[CommandStatus]):
 
         command = self if not self.parent else self.parent
 
-        result: Awaitable[Any] | None = self.actor.write(
+        result: Optional[Awaitable[Any]] = self.actor.write(
             message_code,
             message=message,
             command=command,
@@ -306,7 +306,7 @@ class Command(BaseCommand):
         )
 
 
-def parse_legacy_command(command_string: str) -> tuple[int, str]:
+def parse_legacy_command(command_string: str) -> Tuple[int, str]:
     """Parses a command received by a legacy actor.
 
     Parameters
