@@ -4,6 +4,8 @@ Core classes for SDSS-3 keyword validation
 Refer to https://trac.sdss3.org/wiki/Ops/Validation for details.
 """
 
+# type: ignore
+
 # Created 18-Nov-2008 by David Kirkby (dkirkby@uci.edu)
 
 import collections
@@ -33,19 +35,19 @@ class Consumer(object):
 
     def trace(self, what):
         if self.debug:
-            print('%s%r << %r' % (' ' * Consumer.indent, self, what))
+            print("%s%r << %r" % (" " * Consumer.indent, self, what))
             Consumer.indent += 1
 
     def passed(self, what):
         if self.debug:
             Consumer.indent -= 1
-            print('%sPASS >> %r' % (' ' * Consumer.indent, what))
+            print("%sPASS >> %r" % (" " * Consumer.indent, what))
         return True
 
     def failed(self, reason):
         if self.debug:
             Consumer.indent -= 1
-            print('%sFAIL: %s' % (' ' * Consumer.indent, reason))
+            print("%sFAIL: %s" % (" " * Consumer.indent, reason))
         return False
 
     def consume(self, what):
@@ -64,7 +66,7 @@ class TypedValues(Consumer):
         for vtype in vtypes:
             if isinstance(vtype, protoTypes.RepeatedValueType):
                 if vtype.minRepeat != vtype.maxRepeat and vtype is not vtypes[-1]:
-                    raise KeysError('Repetition range only allowed for last value type')
+                    raise KeysError("Repetition range only allowed for last value type")
                 self.minVals += vtype.minRepeat
                 if self.maxVals is not None and vtype.maxRepeat is not None:
                     self.maxVals += vtype.maxRepeat
@@ -82,18 +84,18 @@ class TypedValues(Consumer):
             elif isinstance(vtype, protoTypes.ByName):
                 self.vtypes.append(vtype)
             else:
-                raise KeysError('Invalid value type: %r' % vtype)
+                raise KeysError("Invalid value type: %r" % vtype)
         if self.maxVals == 0:
-            self.descriptor = 'none'
+            self.descriptor = "none"
         elif self.maxVals == self.minVals:
             self.descriptor = self.minVals
         elif self.maxVals is None:
-            self.descriptor = '%d or more' % self.minVals
+            self.descriptor = "%d or more" % self.minVals
         else:
-            self.descriptor = '%d-%d' % (self.minVals, self.maxVals)
+            self.descriptor = "%d-%d" % (self.minVals, self.maxVals)
 
     def __repr__(self):
-        return 'Types%r' % self.vtypes
+        return "Types%r" % self.vtypes
 
     def consume(self, values):
         self.trace(values)
@@ -109,21 +111,27 @@ class TypedValues(Consumer):
                 while offset < typeToConsume.minRepeat:
                     if not self.consumeNextValue(vtype, values):
                         values[:] = self.originalValues
-                        return self.failed('expected repeated value type %r' % typeToConsume)
+                        return self.failed(
+                            "expected repeated value type %r" % typeToConsume
+                        )
                     offset += 1
-                while typeToConsume.maxRepeat is None or offset < typeToConsume.maxRepeat:
+                while (
+                    typeToConsume.maxRepeat is None or offset < typeToConsume.maxRepeat
+                ):
                     if not self.consumeNextValue(vtype, values):
                         break
                     offset += 1
             elif isinstance(typeToConsume, protoTypes.ValueType):
                 if not self.consumeNextValue(typeToConsume, values):
                     values[:] = self.originalValues
-                    return self.failed('expected value type %r' % typeToConsume)
+                    return self.failed("expected value type %r" % typeToConsume)
             elif isinstance(typeToConsume, protoTypes.CompoundValueType):
                 for vtype in typeToConsume.vtypes:
                     if not self.consumeNextValue(vtype, values):
                         values[:] = self.originalValues
-                        return self.failed('expected compound value type %r' % typeToConsume)
+                        return self.failed(
+                            "expected compound value type %r" % typeToConsume
+                        )
                 # Optionally replace the values with a reference to a single object
                 # initialized with the values. The default object is a tuple.
                 if protoTypes.CompoundValueType.WrapEnable:
@@ -133,10 +141,10 @@ class TypedValues(Consumer):
                         wrapped = typeToConsume.wrapper(*wrapped)
                     values[-size:] = [wrapped]
             else:
-                raise KeysError('Unexpected typeToConsume: %r' % typeToConsume)
+                raise KeysError("Unexpected typeToConsume: %r" % typeToConsume)
         if self.index != len(self.originalValues):
             values[:] = self.originalValues
-            return self.failed('not all values consumed: %s' % values[self.index:])
+            return self.failed("not all values consumed: %s" % values[self.index :])
         return self.passed(values)
 
     def consumeNextValue(self, valueType, values):
@@ -154,20 +162,22 @@ class TypedValues(Consumer):
     def describeAsHTML(self):
         content = utilHtml.Div(
             utilHtml.Div(
-                utilHtml.Span('Values', className='label'),
-                utilHtml.Span(self.descriptor, className='value'),
-                className='key descriptor'),
-            className='vtypes')
+                utilHtml.Span("Values", className="label"),
+                utilHtml.Span(self.descriptor, className="value"),
+                className="key descriptor",
+            ),
+            className="vtypes",
+        )
         for vtype in self.vtypes:
-            content.append(utilHtml.Div(utilHtml.Entity('nbsp'), className='separator'))
+            content.append(utilHtml.Div(utilHtml.Entity("nbsp"), className="separator"))
             content.extend(vtype.describeAsHTML().children)
         return content
 
     def describe(self):
-        text = '%12s: %s\n' % ('Values', self.descriptor)
+        text = "%12s: %s\n" % ("Values", self.descriptor)
         for vtype in self.vtypes:
-            extra = vtype.describe().replace('\n', '\n    ')
-            text += '\n    %s\n' % extra
+            extra = vtype.describe().replace("\n", "\n    ")
+            text += "\n    %s\n" % extra
         return text
 
 
@@ -187,23 +197,23 @@ class Key(Consumer):
     def __init__(self, name, *vtypes, **metadata):
         self.name = name
         self.typedValues = TypedValues(vtypes)
-        self.help = metadata.get('help', None)
-        self.refreshCmd = metadata.get('refreshCmd', None)
+        self.help = metadata.get("help", None)
+        self.refreshCmd = metadata.get("refreshCmd", None)
         defDoCache = (self.typedValues.maxVals != 0) and not self.refreshCmd
-        self.doCache = bool(metadata.get('doCache', defDoCache))
-        if 'unique' in metadata:
-            self.unique = metadata.get('unique')
+        self.doCache = bool(metadata.get("doCache", defDoCache))
+        if "unique" in metadata:
+            self.unique = metadata.get("unique")
 
     def __repr__(self):
-        return 'Key(%s)' % self.name
+        return "Key(%s)" % self.name
 
     def consume(self, keyword):
         self.trace(keyword)
         # perform a case-insensitive name matching
         if keyword.name.lower() != self.name.lower():
-            return self.failed('keyword has wrong name')
+            return self.failed("keyword has wrong name")
         if not self.typedValues.consume(keyword.values):
-            return self.failed('no match for keyword values')
+            return self.failed("no match for keyword values")
         keyword.matched = True
         return self.passed(keyword)
 
@@ -219,29 +229,36 @@ class Key(Consumer):
             values = values[0]
         keyword = protoMess.Keyword(self.name, values)
         if not self.consume(keyword):
-            raise KeysError('value types do not match for keyword %s: %r' % (self.name, values))
+            raise KeysError(
+                "value types do not match for keyword %s: %r" % (self.name, values)
+            )
         return keyword
 
     def describeAsHTML(self):
-        content = utilHtml.Div(utilHtml.Div(self.name, className='keyname'), className='key')
-        desc = utilHtml.Div(className='keydesc')
+        content = utilHtml.Div(
+            utilHtml.Div(self.name, className="keyname"), className="key"
+        )
+        desc = utilHtml.Div(className="keydesc")
         content.append(desc)
         if self.help:
             desc.append(
                 utilHtml.Div(
-                    utilHtml.Span('Description', className='label'),
-                    utilHtml.Span(self.help, className='value'),
-                    className='key descriptor'))
+                    utilHtml.Span("Description", className="label"),
+                    utilHtml.Span(self.help, className="value"),
+                    className="key descriptor",
+                )
+            )
         desc.extend(self.typedValues.describeAsHTML().children)
         return content
 
     def describe(self):
-        text = '%12s: %s\n' % ('Keyword', self.name)
+        text = "%12s: %s\n" % ("Keyword", self.name)
         if self.help:
-            pad = '\n' + ' ' * 14
+            pad = "\n" + " " * 14
             formatted = textwrap.fill(
-                textwrap.dedent(self.help).strip(), width=66).replace('\n', pad)
-            text += '%12s: %s\n' % ('Description', formatted)
+                textwrap.dedent(self.help).strip(), width=66
+            ).replace("\n", pad)
+            text += "%12s: %s\n" % ("Description", formatted)
         text += self.typedValues.describe()
         return text
 
@@ -260,7 +277,7 @@ class KeysManager(object):
     @classmethod
     def addKeys(cls, kdict):
         if not isinstance(kdict, KeysDictionary):
-            raise KeysError('Cmd keys must be provided as a KeysDictionary')
+            raise KeysError("Cmd keys must be provided as a KeysDictionary")
         cls.keys[kdict.name] = kdict
 
     @classmethod
@@ -268,7 +285,7 @@ class KeysManager(object):
         for kdict in cls.keys.values():
             if name in kdict:
                 return kdict[name]
-        raise KeysError('No such registered keyword <%s>' % name)
+        raise KeysError("No such registered keyword <%s>" % name)
 
 
 class CmdKey(Consumer, KeysManager):
@@ -280,15 +297,15 @@ class CmdKey(Consumer, KeysManager):
         self.key = key
 
     def __repr__(self):
-        return 'CmdKey(%s)' % self.key.name
+        return "CmdKey(%s)" % self.key.name
 
     def consume(self, where):
         self.trace(where)
         keyword = where.keyword()
         if not keyword:
-            return self.failed('no keywords available to consume')
+            return self.failed("no keywords available to consume")
         if not self.key.consume(keyword):
-            return self.failed('no match for command keyword')
+            return self.failed("no match for command keyword")
         where.advance()
         return self.passed(where)
 
@@ -302,9 +319,9 @@ class RawKey(Consumer):
         self.trace(where)
         keyword = where.keyword()
         if not keyword:
-            return self.failed('no keywords available to consume')
+            return self.failed("no keywords available to consume")
         if not isinstance(keyword, protoMess.RawKeyword):
-            return self.failed('no match for raw keyword')
+            return self.failed("no match for raw keyword")
         # no re-casting as a typed value needed here
         where.advance()
         return self.passed(where)
@@ -321,6 +338,7 @@ class KeysDictionary(object):
     The dictionary name is typically the name of an actor. Contains a
     registry of all known KeysDictionaries, for use by the load method.
     """
+
     registry = {}
 
     def __init__(self, name, version, *keys):
@@ -336,10 +354,12 @@ class KeysDictionary(object):
             (major, minor) = map(int, version)
         except (ValueError, TypeError):
             raise KeysDictionaryError(
-                'Invalid version: expected (major,minor) tuple of integers, got %r' % version)
+                "Invalid version: expected (major,minor) tuple of integers, got %r"
+                % version
+            )
         self.version = version
         if not name == name.lower():
-            raise KeysDictionaryError('Invalid name: must be lower case: %s' % name)
+            raise KeysDictionaryError("Invalid name: must be lower case: %s" % name)
         KeysDictionary.registry[name] = self
         self.keys = collections.OrderedDict()
         self.namedTypes = {}
@@ -356,14 +376,14 @@ class KeysDictionary(object):
         exception.
         """
         if not isinstance(key, Key):
-            raise KeysDictionaryError('KeysDictionary can only contain Keys')
-        name = getattr(key, 'unique', key.name)
+            raise KeysDictionaryError("KeysDictionary can only contain Keys")
+        name = getattr(key, "unique", key.name)
         if name.lower() in self.keys:
-            raise KeysDictionaryError('KeysDictionary name is not unique: %s' % name)
+            raise KeysDictionaryError("KeysDictionary name is not unique: %s" % name)
         # look for named types used by the key
         localNames = {}
         for index, vtype in enumerate(key.typedValues.vtypes):
-            vname = getattr(vtype, 'name', None)
+            vname = getattr(vtype, "name", None)
             if isinstance(vtype, protoTypes.ByName):
                 try:
                     key.typedValues.vtypes[index] = self.namedTypes[vname]
@@ -380,7 +400,7 @@ class KeysDictionary(object):
     def extend(self, keyList):
         """Adds all the keys in a list."""
 
-        assert isinstance(keyList, (list, tuple)), 'keyList must be a list or tuple'
+        assert isinstance(keyList, (list, tuple)), "keyList must be a list or tuple"
 
         for key in keyList:
             self.add(key)
@@ -397,7 +417,7 @@ class KeysDictionary(object):
         """
         text = 'Keys Dictionary for "%s" version %r\n' % (self.name, self.version)
         for name in sorted(self.keys):
-            text += '\n' + self.keys[name].describe()
+            text += "\n" + self.keys[name].describe()
         return text
 
     def describeAsHTML(self):
@@ -406,10 +426,12 @@ class KeysDictionary(object):
         """
         content = utilHtml.Div(
             utilHtml.Div(
-                utilHtml.Span(self.name, className='actorName'),
-                utilHtml.Span('%d.%d' % self.version, className='actorVersion'),
-                className='actorHeader'),
-            className='actor')
+                utilHtml.Span(self.name, className="actorName"),
+                utilHtml.Span("%d.%d" % self.version, className="actorVersion"),
+                className="actorHeader",
+            ),
+            className="actor",
+        )
         for name in sorted(self.keys):
             content.append(self.keys[name].describeAsHTML())
         return content
@@ -430,42 +452,46 @@ class KeysDictionary(object):
         try:
             # get the path corresponding to the actorkeys package
             import actorkeys  # noqa
-            keyspath = sys.modules['actorkeys'].__path__
+
+            keyspath = sys.modules["actorkeys"].__path__
         except ImportError:
-            raise KeysDictionaryError('no actorkeys package found')
+            raise KeysDictionaryError("no actorkeys package found")
         try:
             # open the file corresponding to the requested keys dictionary
-            modulespec = importlib.util.find_spec('actorkeys.' + dictname, keyspath)
+            modulespec = importlib.util.find_spec("actorkeys." + dictname, keyspath)
             # create a global symbol table for evaluating the keys
             # dictionary expression
             symbols = {
-                '__builtins__': __builtins__,
-                'Key': Key,
-                'KeysDictionary': KeysDictionary,
-                'ByName': protoTypes.ByName,
+                "__builtins__": __builtins__,
+                "Key": Key,
+                "KeysDictionary": KeysDictionary,
+                "ByName": protoTypes.ByName,
             }
             for (name, value) in protoTypes.__dict__.items():
-                if isinstance(value, type) and issubclass(value, (protoTypes.ValueType,
-                                                                  protoTypes.CompoundValueType)):
+                if isinstance(value, type) and issubclass(
+                    value, (protoTypes.ValueType, protoTypes.CompoundValueType)
+                ):
                     symbols[name] = value
             # evaluate the keys dictionary as a python expression
             filedata = open(modulespec.origin).read()
             kdict = eval(filedata, symbols)
             # check that the dictionary filename and name match
             if not dictname == kdict.name:
-                raise KeysDictionaryError('dictionary filename and name '
-                                          'are different: %s, %s' %
-                                          (modulespec.name, kdict.name))
+                raise KeysDictionaryError(
+                    "dictionary filename and name "
+                    "are different: %s, %s" % (modulespec.name, kdict.name)
+                )
             # do a checksum so that we can detect changes
             # independently of versioning
             kdict.checksum = hashlib.md5(filedata.encode()).hexdigest()
             return kdict
         except ImportError as e:
-            raise KeysDictionaryError('no keys dictionary found '
-                                      'for %s: %s' % (dictname, str(e)))
+            raise KeysDictionaryError(
+                "no keys dictionary found " "for %s: %s" % (dictname, str(e))
+            )
         except Exception as e:
-            indent = '\n >> '
-            description = indent + indent.join(str(e).split('\n'))
-            raise KeysDictionaryError('badly formatted keys '
-                                      'dictionary in %s:%s' % (dictname,
-                                                               description))
+            indent = "\n >> "
+            description = indent + indent.join(str(e).split("\n"))
+            raise KeysDictionaryError(
+                "badly formatted keys " "dictionary in %s:%s" % (dictname, description)
+            )
